@@ -58,7 +58,7 @@
 #include "totem-options.h"
 #include "totem-uri.h"
 #include "totem-interface.h"
-#include "totem-volume.h"
+#include "bacon-volume.h"
 #include "video-utils.h"
 
 #include "totem.h"
@@ -546,18 +546,12 @@ totem_action_fullscreen_toggle (Totem *totem)
 			totem->controls_visibility = TOTEM_CONTROLS_HIDDEN;
 			show_controls (totem, TRUE);
 		}
-
-		if (totem_sidebar_is_visible (totem) != FALSE)
-			gtk_widget_show (totem->sidebar);
-		else
-			gtk_widget_hide (totem->sidebar);
 	} else {
 		totem_action_save_size (totem);
 		update_fullscreen_size (totem);
 		bacon_video_widget_set_fullscreen (totem->bvw, TRUE);
 		bacon_video_widget_set_show_cursor (totem->bvw, FALSE);
 		gtk_window_fullscreen (GTK_WINDOW(totem->win));
-		gtk_widget_hide (totem->sidebar);
 
 		if (bacon_video_widget_is_playing (totem->bvw) != FALSE)
 			totem_scrsaver_disable (totem->scr);
@@ -677,7 +671,6 @@ gboolean
 totem_action_set_mrl_with_warning (Totem *totem, const char *mrl,
 		gboolean warn)
 {
-	GtkWidget *widget;
 	gboolean retval = TRUE;
 
 	if (totem->mrl != NULL)
@@ -697,42 +690,31 @@ totem_action_set_mrl_with_warning (Totem *totem, const char *mrl,
 
 		/* Play/Pause */
 		gtk_widget_set_sensitive (totem->pp_button, FALSE);
-		widget = glade_xml_get_widget (totem->xml, "tmw_play_menu_item");
-		gtk_widget_set_sensitive (widget, FALSE);
 
-		widget = glade_xml_get_widget (totem->xml_popup, "trcm_play");
-		gtk_widget_set_sensitive (widget, FALSE);
+		totem_main_set_sensitivity ("tmw_play_menu_item", FALSE);
+		totem_popup_set_sensitivity ("trcm_play", FALSE);
 
 		/* Seek bar and seek buttons */
 		update_seekable (totem, FALSE);
 
 		/* Volume */
-		widget = glade_xml_get_widget (totem->xml, "tcw_volume_button");
-		gtk_widget_set_sensitive (widget, FALSE);
-		widget = glade_xml_get_widget (totem->xml_popup, "trcm_volume_up");
-		gtk_widget_set_sensitive (widget, FALSE);
-		widget = glade_xml_get_widget (totem->xml_popup, "trcm_volume_down");
-		gtk_widget_set_sensitive (widget, FALSE);
+		totem_main_set_sensitivity ("tcw_volume_button", FALSE);
+		totem_main_set_sensitivity ("tmw_volume_up_menu_item", FALSE);
+		totem_main_set_sensitivity ("tmw_volume_down_menu_item", FALSE);
+		totem_popup_set_sensitivity ("trcm_volume_up", FALSE);
+		totem_popup_set_sensitivity ("trcm_volume_down", FALSE);
 
 		/* Control popup */
 		gtk_widget_set_sensitive (totem->fs_seek, FALSE);
 		gtk_widget_set_sensitive (totem->fs_pp_button, FALSE);
-		widget = glade_xml_get_widget (totem->xml,
-				"tcw_previous_button");
-		gtk_widget_set_sensitive (widget, FALSE);
-		widget = glade_xml_get_widget (totem->xml, "tcw_next_button"); 
-		gtk_widget_set_sensitive (widget, FALSE);
-		widget = glade_xml_get_widget (totem->xml_popup, "trcm_next_chapter");
-		gtk_widget_set_sensitive (widget, FALSE);
-		widget = glade_xml_get_widget (totem->xml_popup, "trcm_previous_chapter");
-		gtk_widget_set_sensitive (widget, FALSE);
-		widget = glade_xml_get_widget (totem->xml, "tcw_volume_hbox");
-		gtk_widget_set_sensitive (widget, FALSE);
+		totem_main_set_sensitivity ("tcw_previous_button", FALSE);
+		totem_main_set_sensitivity ("tcw_next_button", FALSE);
+		totem_popup_set_sensitivity ("trcm_next_chapter", FALSE);
+		totem_popup_set_sensitivity ("trcm_previous_chapter", FALSE);
+		totem_main_set_sensitivity ("tcw_volume_hbox", FALSE);
 
 		/* Take a screenshot */
-		widget = glade_xml_get_widget (totem->xml,
-				"tmw_take_screenshot_menu_item");
-		gtk_widget_set_sensitive (widget, FALSE);
+		totem_main_set_sensitivity ("tmw_take_screenshot_menu_item", FALSE);
 
 		/* Set the logo */
 		bacon_video_widget_set_logo_mode (totem->bvw, TRUE);
@@ -756,11 +738,9 @@ totem_action_set_mrl_with_warning (Totem *totem, const char *mrl,
 		totem->mrl = g_strdup (mrl);
 
 		/* Play/Pause */
+		totem_main_set_sensitivity ("tmw_play_menu_item", TRUE);
 		gtk_widget_set_sensitive (totem->pp_button, TRUE);
-		widget = glade_xml_get_widget (totem->xml, "tmw_play_menu_item");
-		gtk_widget_set_sensitive (widget, TRUE);
-		widget = glade_xml_get_widget (totem->xml_popup, "trcm_play");
-		gtk_widget_set_sensitive (widget, TRUE);
+		totem_popup_set_sensitivity ("trcm_play", TRUE);
 		gtk_widget_set_sensitive (totem->fs_pp_button, TRUE);
 
 		/* Seek bar */
@@ -769,18 +749,16 @@ totem_action_set_mrl_with_warning (Totem *totem, const char *mrl,
 
 		/* Volume */
 		caps = bacon_video_widget_can_set_volume (totem->bvw);
-		widget = glade_xml_get_widget (totem->xml, "tcw_volume_button");
-		gtk_widget_set_sensitive (widget, caps);
-		widget = glade_xml_get_widget (totem->xml, "tcw_volume_hbox");
-		gtk_widget_set_sensitive (widget, caps);
-		widget = glade_xml_get_widget (totem->xml_popup, "trcm_volume_up");                gtk_widget_set_sensitive (widget, caps);
-		widget = glade_xml_get_widget (totem->xml_popup, "trcm_volume_down");
-		gtk_widget_set_sensitive (widget, caps);
+		totem_main_set_sensitivity ("tcw_volume_button", caps);
+		totem_main_set_sensitivity ("tcw_volume_hbox", caps);
+		totem_popup_set_sensitivity ("trcm_volume_up", caps);
+		totem_popup_set_sensitivity ("trcm_volume_down", caps);
+		totem_main_set_sensitivity ("tmw_volume_up_menu_item", caps);
+		totem_main_set_sensitivity ("tmw_volume_down_menu_item", caps);
 
 		/* Take a screenshot */
-		widget = glade_xml_get_widget (totem->xml,
-				"tmw_take_screenshot_menu_item");
-		gtk_widget_set_sensitive (widget, retval);
+		totem_main_set_sensitivity ("tmw_take_screenshot_menu_item",
+				retval);
 
 		/* Set the playlist */
 		totem_playlist_set_playing (totem->playlist, retval);
@@ -807,8 +785,7 @@ totem_action_set_mrl_with_warning (Totem *totem, const char *mrl,
 	update_buttons (totem);
 	update_media_menu_items (totem);
 
-	widget = glade_xml_get_widget (totem->xml, "tmw_properties_menu_item");
-	gtk_widget_set_sensitive (widget, retval);
+	totem_main_set_sensitivity ("tmw_properties_menu_item", retval);
 
 	return retval;
 }
@@ -909,41 +886,23 @@ totem_action_seek_relative (Totem *totem, int off_sec)
 static void
 totem_action_zoom (Totem *totem, int zoom)
 {
-	GtkWidget *item;
-
 	if (zoom < ZOOM_LOWER || zoom > ZOOM_UPPER)
 		return;
 
 	bacon_video_widget_set_zoom (totem->bvw, zoom);
 
 	if (zoom == ZOOM_UPPER) {
-		item = glade_xml_get_widget
-			(totem->xml, "tmw_zoom_in_menu_item");
-		gtk_widget_set_sensitive (item, FALSE);
+		totem_main_set_sensitivity ("tmw_zoom_in_menu_item", FALSE);
 	} else if (zoom == ZOOM_LOWER) {
-		item = glade_xml_get_widget
-			(totem->xml, "tmw_zoom_out_menu_item");
-		gtk_widget_set_sensitive (item, FALSE);
+		totem_main_set_sensitivity ("tmw_zoom_out_menu_item", FALSE);
 	} else if (zoom == ZOOM_RESET) {
-		item = glade_xml_get_widget
-			(totem->xml, "tmw_zoom_reset_menu_item");
-		gtk_widget_set_sensitive (item, FALSE);
-		item = glade_xml_get_widget
-			(totem->xml, "tmw_zoom_in_menu_item");
-		gtk_widget_set_sensitive (item, TRUE);
-		item = glade_xml_get_widget
-			(totem->xml, "tmw_zoom_out_menu_item");
-		gtk_widget_set_sensitive (item, TRUE);
+		totem_main_set_sensitivity ("tmw_zoom_reset_menu_item", FALSE);
+		totem_main_set_sensitivity ("tmw_zoom_in_menu_item", TRUE);
+		totem_main_set_sensitivity ("tmw_zoom_out_menu_item", TRUE);
 	} else {
-		item = glade_xml_get_widget
-			(totem->xml, "tmw_zoom_in_menu_item");
-		gtk_widget_set_sensitive (item, TRUE);
-		item = glade_xml_get_widget
-			(totem->xml, "tmw_zoom_out_menu_item");
-		gtk_widget_set_sensitive (item, TRUE);
-		item = glade_xml_get_widget
-			(totem->xml, "tmw_zoom_reset_menu_item");
-		gtk_widget_set_sensitive (item, TRUE);
+		totem_main_set_sensitivity ("tmw_zoom_in_menu_item", TRUE);
+		totem_main_set_sensitivity ("tmw_zoom_out_menu_item", TRUE);
+		totem_main_set_sensitivity ("tmw_zoom_reset_menu_item", TRUE);
 	}
 }
 
@@ -1274,9 +1233,9 @@ on_error_event (BaconVideoWidget *bvw, char *message,
 		play_pause_set_label (totem, STATE_STOPPED);
 
 	if (fatal == FALSE) {
-		totem_action_error (_("An error occured"), message, totem);
+		totem_action_error (_("An error occurred"), message, totem);
 	} else {
-		totem_action_error_and_exit (_("An error occured"),
+		totem_action_error_and_exit (_("An error occurred"),
 				message, totem);
 	}
 }
@@ -1296,8 +1255,6 @@ on_buffering_event (BaconVideoWidget *bvw, int percentage, Totem *totem)
 static void
 update_seekable (Totem *totem, gboolean seekable)
 {
-	GtkWidget *widget;
-
 	if (totem->seekable == seekable)
 		return;
 
@@ -1307,25 +1264,15 @@ update_seekable (Totem *totem, gboolean seekable)
 	gtk_widget_set_sensitive (totem->seek, seekable);
 	gtk_widget_set_sensitive (totem->fs_seek, seekable);
 
-	widget = glade_xml_get_widget (totem->xml, "tmw_seek_hbox");
-	gtk_widget_set_sensitive (widget, seekable);
+	totem_main_set_sensitivity ("tmw_seek_hbox", seekable);
 
-	widget = glade_xml_get_widget (totem->xml, "tcw_time_hbox");
-	gtk_widget_set_sensitive (widget, seekable);
+	totem_main_set_sensitivity ("tcw_time_hbox", seekable);
 
-	widget = glade_xml_get_widget (totem->xml,
-			"tmw_skip_forward_menu_item");
-	gtk_widget_set_sensitive (widget, seekable);
-	widget = glade_xml_get_widget (totem->xml,
-			"tmw_skip_backwards_menu_item");
-	gtk_widget_set_sensitive (widget, seekable);
-	widget = glade_xml_get_widget (totem->xml_popup, "trcm_skip_forward");
-	gtk_widget_set_sensitive (widget, seekable);
-	widget = glade_xml_get_widget (totem->xml_popup,
-			"trcm_skip_backwards");
-	gtk_widget_set_sensitive (widget, seekable);
-	widget = glade_xml_get_widget (totem->xml, "tmw_skip_to_menu_item");
-	gtk_widget_set_sensitive (widget, seekable);
+	totem_main_set_sensitivity ("tmw_skip_forward_menu_item", seekable);
+	totem_main_set_sensitivity ("tmw_skip_backwards_menu_item", seekable);
+	totem_popup_set_sensitivity ("trcm_skip_forward", seekable);
+	totem_popup_set_sensitivity ("trcm_skip_backwards", seekable);
+	totem_main_set_sensitivity ("tmw_skip_to_menu_item", seekable);
 	if (totem->skipto)
 		totem_skipto_set_seekable (totem->skipto, seekable);
 }
@@ -1393,8 +1340,8 @@ update_volume_sliders (Totem *totem)
 				totem->prev_volume != -1 && volume != -1))
 	{
 		totem->volume_first_time = 0;
-		totem_volume_button_set_value (
-			TOTEM_VOLUME_BUTTON (totem->volume), (float) volume);
+		bacon_volume_button_set_value (
+			BACON_VOLUME_BUTTON (totem->volume), (float) volume);
 		gtk_adjustment_set_value (totem->fs_voladj,
 				(float) volume);
 	}
@@ -1474,12 +1421,12 @@ vol_cb (GtkWidget *widget, Totem *totem)
 				(totem->bvw, (gint) totem->fs_voladj->value);
 
 			/* Update the fullscreen volume adjustment */
-			totem_volume_button_set_value (
-				TOTEM_VOLUME_BUTTON (totem->volume),
+			bacon_volume_button_set_value (
+				BACON_VOLUME_BUTTON (totem->volume),
 				gtk_adjustment_get_value (totem->fs_voladj));
 		} else {
-			int value = totem_volume_button_get_value (
-				TOTEM_VOLUME_BUTTON (totem->volume));
+			int value = bacon_volume_button_get_value (
+				BACON_VOLUME_BUTTON (totem->volume));
 
 			bacon_video_widget_set_volume (totem->bvw, value);
 			/* Update the volume adjustment */
@@ -1850,6 +1797,11 @@ show_controls (Totem *totem, gboolean was_fullscreen)
 		gtk_widget_show (menubar);
 		gtk_widget_show (controlbar);
 		gtk_widget_show (statusbar);
+		if (totem_sidebar_is_visible (totem) != FALSE)
+			gtk_widget_show (totem->sidebar);
+		else
+			gtk_widget_hide (totem->sidebar);
+
 		gtk_widget_hide (item);
 		gtk_container_set_border_width (GTK_CONTAINER (bvw_vbox),
 				BVW_VBOX_BORDER_WIDTH);
@@ -1869,6 +1821,7 @@ show_controls (Totem *totem, gboolean was_fullscreen)
 		gtk_widget_hide (menubar);
 		gtk_widget_hide (controlbar);
 		gtk_widget_hide (statusbar);
+		gtk_widget_hide (totem->sidebar);
 
 		 /* We won't show controls in fullscreen */
 		if (totem_is_fullscreen (totem) != FALSE)
@@ -2654,11 +2607,7 @@ totem_action_handle_key (Totem *totem, GdkEventKey *event)
 #endif /* HAVE_XFREE */
 	case GDK_p:
 	case GDK_P:
-		/* Playlist keyboard shortcut? */
-		if (event->state & GDK_CONTROL_MASK)
-			totem_sidebar_toggle (totem);
-		else
-			totem_action_play_pause (totem);
+		totem_action_play_pause (totem);
 		break;
 	case GDK_q:
 	case GDK_Q:
@@ -2786,14 +2735,12 @@ totem_action_handle_volume_scroll (Totem *totem, GdkScrollDirection direction)
 static int
 on_window_key_press_event (GtkWidget *win, GdkEventKey *event, Totem *totem)
 {
-	/* Special case the Playlist, Eject, Open, Open URI and
+	/* Special case Eject, Open, Open URI and
 	 * seeking keyboard shortcuts */
 	if (event->state != 0
 			&& (event->state & GDK_CONTROL_MASK))
 	{
 		switch (event->keyval)
-		case GDK_p:
-		case GDK_P:
 		case GDK_E:
 		case GDK_e:
 		case GDK_O:
@@ -2834,32 +2781,24 @@ on_volume_scroll_event (GtkWidget *win, GdkEventScroll *event, Totem *totem)
 static void
 update_media_menu_items (Totem *totem)
 {
-        GtkWidget *item;
         gboolean playing;
 
 	playing = totem_playing_dvd (totem->mrl);
 
-	item = glade_xml_get_widget (totem->xml, "tmw_dvd_root_menu_item");
-	gtk_widget_set_sensitive (item, playing);
-        item = glade_xml_get_widget (totem->xml, "tmw_dvd_title_menu_item");
-	gtk_widget_set_sensitive (item, playing);
-        item = glade_xml_get_widget (totem->xml, "tmw_dvd_audio_menu_item");
-	gtk_widget_set_sensitive (item, playing);
-        item = glade_xml_get_widget (totem->xml, "tmw_dvd_angle_menu_item");
-	gtk_widget_set_sensitive (item, playing);
-        item = glade_xml_get_widget (totem->xml, "tmw_dvd_chapter_menu_item");
-	gtk_widget_set_sensitive (item, playing);
+	totem_main_set_sensitivity ("tmw_dvd_root_menu_item", playing);
+	totem_main_set_sensitivity ("tmw_dvd_title_menu_item", playing);
+	totem_main_set_sensitivity ("tmw_dvd_audio_menu_item", playing);
+	totem_main_set_sensitivity ("tmw_dvd_angle_menu_item", playing);
+	totem_main_set_sensitivity ("tmw_dvd_chapter_menu_item", playing);
 
 	playing = totem_is_media (totem->mrl);
 
-	item = glade_xml_get_widget (totem->xml, "tmw_eject_menu_item");
-	gtk_widget_set_sensitive (item, playing);
+	totem_main_set_sensitivity ("tmw_eject_menu_item", playing);
 }
 
 static void
 update_buttons (Totem *totem)
 {
-	GtkWidget *item;
 	gboolean has_item;
 
 	/* Previous */
@@ -2871,15 +2810,10 @@ update_buttons (Totem *totem)
 		has_item = totem_playlist_has_previous_mrl (totem->playlist);
 	}
 
-	item = glade_xml_get_widget (totem->xml, "tmw_previous_button");
-	gtk_widget_set_sensitive (item, has_item);
-	item = glade_xml_get_widget (totem->xml, "tcw_previous_button");
-	gtk_widget_set_sensitive (item, has_item);
-	item = glade_xml_get_widget (totem->xml,
-			"tmw_previous_chapter_menu_item");
-	gtk_widget_set_sensitive (item, has_item);
-	item = glade_xml_get_widget (totem->xml_popup, "trcm_previous_chapter");
-	gtk_widget_set_sensitive (item, has_item);
+	totem_main_set_sensitivity ("tmw_previous_button", has_item);
+	totem_main_set_sensitivity ("tcw_previous_button", has_item);
+	totem_main_set_sensitivity ("tmw_previous_chapter_menu_item", has_item);
+	totem_popup_set_sensitivity ("trcm_previous_chapter", has_item);
 
 	/* Next */
 	/* FIXME Need way to detect if DVD Title has no more chapters */
@@ -2890,14 +2824,10 @@ update_buttons (Totem *totem)
 		has_item = totem_playlist_has_next_mrl (totem->playlist);
 	}
 
-	item = glade_xml_get_widget (totem->xml, "tmw_next_button");
-	gtk_widget_set_sensitive (item, has_item);
-	item = glade_xml_get_widget (totem->xml, "tcw_next_button");
-	gtk_widget_set_sensitive (item, has_item);
-	item = glade_xml_get_widget (totem->xml, "tmw_next_chapter_menu_item");
-	gtk_widget_set_sensitive (item, has_item);
-	item = glade_xml_get_widget (totem->xml_popup, "trcm_next_chapter");
-	gtk_widget_set_sensitive (item, has_item);
+	totem_main_set_sensitivity ("tmw_next_button", has_item);
+	totem_main_set_sensitivity ("tcw_next_button", has_item);
+	totem_main_set_sensitivity ("tmw_next_chapter_menu_item", has_item);
+	totem_popup_set_sensitivity ("trcm_next_chapter", has_item);
 }
 
 static void
@@ -3408,7 +3338,8 @@ totem_volume_create (void)
 {
 	GtkWidget *widget;
 
-	widget = totem_volume_button_new (0, 100, -1);
+	widget = bacon_volume_button_new (GTK_ICON_SIZE_SMALL_TOOLBAR,
+					  0, 100, -1);
 	gtk_widget_show (widget);
 
 	return widget;
